// generated by CommonLibrary.cmake, do not edit.

/**
 * @file include/deflect/version.h
 * Defines version macros and class for library Deflect.
 */

#ifndef DEFLECT_VERSION_H
#define DEFLECT_VERSION_H

#include <deflect/api.h>
#include <string>

namespace deflect
{
    /** The current major version. */
#   define DEFLECT_VERSION_MAJOR 1

    /** The current minor version. */
#   define DEFLECT_VERSION_MINOR 0

    /** The current patch level. */
#   define DEFLECT_VERSION_PATCH 2

    /** The current SCM revision. */
#   define DEFLECT_VERSION_REVISION 0xa0f8ab8

    /** The current binary interface. */
#   define DEFLECT_VERSION_ABI 7ull

    /** The current major.minor.version as a string. */
#   define DEFLECT_VERSION_STRING \
    "1.0.2"

    /** The current major.minor.version.revision as a string. */
#   define DEFLECT_REV_STRING \
    "1.0.2.0xa0f8ab8"

/** True if the current version is newer than the given one. */
#   define DEFLECT_VERSION_GT( MAJOR, MINOR, PATCH )       \
    ( (DEFLECT_VERSION_MAJOR>MAJOR) ||                     \
      (DEFLECT_VERSION_MAJOR==MAJOR && (DEFLECT_VERSION_MINOR>MINOR || \
          (DEFLECT_VERSION_MINOR==MINOR && DEFLECT_VERSION_PATCH>PATCH))))

/** True if the current version is equal or newer to the given. */
#   define DEFLECT_VERSION_GE( MAJOR, MINOR, PATCH )       \
    ( (DEFLECT_VERSION_MAJOR>MAJOR) ||                     \
      (DEFLECT_VERSION_MAJOR==MAJOR && (DEFLECT_VERSION_MINOR>MINOR || \
          (DEFLECT_VERSION_MINOR==MINOR && DEFLECT_VERSION_PATCH>=PATCH))))

/** True if the current version is older than the given one. */
#   define DEFLECT_VERSION_LT( MAJOR, MINOR, PATCH )       \
    ( (DEFLECT_VERSION_MAJOR<MAJOR) ||                     \
      (DEFLECT_VERSION_MAJOR==MAJOR && (DEFLECT_VERSION_MINOR<MINOR || \
          (DEFLECT_VERSION_MINOR==MINOR && DEFLECT_VERSION_PATCH<PATCH))))

/** True if the current version is older or equal to the given. */
#   define DEFLECT_VERSION_LE( MAJOR, MINOR, PATCH )       \
    ( (DEFLECT_VERSION_MAJOR<MAJOR) ||                     \
      (DEFLECT_VERSION_MAJOR==MAJOR && (DEFLECT_VERSION_MINOR<MINOR || \
        (DEFLECT_VERSION_MINOR==MINOR && DEFLECT_VERSION_PATCH<=PATCH))))

/** Information about the current Deflect version. */
class DEFLECT_API Version
{
public:
    /** @return the current major version of Deflect. */
    static int getMajor();

    /** @return the current minor version of Deflect. */
    static int getMinor();

    /** @return the current patch level of Deflect. */
    static int getPatch();

    /** @return the current Deflect version (MM.mm.pp). */
    static std::string getString();

    /** @return the SCM revision. */
    static unsigned long long getRevision();

    /** @return the current binary interface version of Deflect. */
    static int getABI();

    /** @return the current Deflect version plus the git SHA hash (MM.mm.pp.rev). */
    static std::string getRevString();

    /**
     * Runtime check for ABI compatibility.
     *
     * Call from code using Deflect. Will fail if the executable
     * was compiled against a version incompatible with the runtime version.
     *
     * @return true if the link-time and compile-time DSO are compatible.
     */
    static bool check()
    {
        return getMajor()==DEFLECT_VERSION_MAJOR &&
               getMinor()==DEFLECT_VERSION_MINOR;
    }

    /** @return JSON schema describing this object. */
    static std::string getSchema()
    {
        return R"(
                {
                  "title": "Version",
                  "type": "object",
                  "description": "Version information of the running application",
                  "properties": {
                    "major": { "type": "integer" },
                    "minor": { "type": "integer" },
                    "patch": { "type": "integer" },
                    "abi": { "type": "integer" },
                    "revision": { "type": "string" }
                  }
               }
               )";
    }

    /** @return JSON-encoded data for this object. */
    static std::string toJSON()
    {
        return R"(
               {
                 "major": 1,
                 "minor": 0,
                 "patch": 2,
                 "abi": 7,
                 "revision": "a0f8ab8"
               }
               )";
    }
};

}

#endif
